//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/CrosscorrelationItems.h
//! @brief     Defines classes CrosscorrelationItem.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2024
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_CROSSCORRELATIONITEMS_H
#define BORNAGAIN_GUI_MODEL_SAMPLE_CROSSCORRELATIONITEMS_H

#include "GUI/Model/Descriptor/DoubleProperty.h"
#include <QXmlStreamReader>

class CrosscorrelationItem {
public:
    virtual ~CrosscorrelationItem() = default;

    virtual void writeTo(QXmlStreamWriter*) const {}
    virtual void readFrom(QXmlStreamReader*) {}
    virtual DoubleProperties crossCorrProperties() = 0;

protected:
    CrosscorrelationItem() = default;
};

class FixedDepthCrosscorrelationItem : public CrosscorrelationItem {
public:
    FixedDepthCrosscorrelationItem(double cross_corr_depth);

    void writeTo(QXmlStreamWriter* w) const override;
    void readFrom(QXmlStreamReader* r) override;

    DoubleProperties crossCorrProperties() override { return {&m_crosscorrelation_depth}; }

private:
    DoubleProperty m_crosscorrelation_depth;
};

#endif // BORNAGAIN_GUI_MODEL_SAMPLE_CROSSCORRELATIONITEMS_H
